{
	"name" : "Sale CRM Stuff",
	"version" : "1.0",
	"author" : "Tiny",
	"website" : "http://tinyerp.com/module_sale.html",
	"depends" : ["sale", "crm"],
	"category" : "Generic Modules/Sales & Purchases",
	"init_xml" : [],
	"demo_xml" : [],
	"update_xml" : ["sale_crm_wizard.xml"],
	"active": False,
	"installable": True
}
